==> rivendell-2.2.0.zip: rivendell-2.2.0/rdcastmanager/rdcastmanager_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation>Podcast editieren</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation>eMail des Autors:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation>Link URL:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation>Quelltext:</translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation>Quell-URL:</translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation>Kommentar-URL:</translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation>Gepostet am:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation>Cast läuft ab:</translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation type="obsolete">Läuft ab am/um:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Auswählen</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Hold</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation>Posting Status:</translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation>Episoden-
&amp;Report</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation>Sendezeit/-Datum:</translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation>Medienlink:</translation>
    </message>
    <message>
        <source>Expires On:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation>Podcastliste</translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation>Poste von
Car&amp;t/Cut</translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation>Poste von
&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation>Abonnement
&amp;Report</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chliessen</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>Herkunft</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Läuf ab</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation>Lade Audio hoch...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <source>Format Error</source>
        <translation type="obsolete">Formatfehler</translation>
    </message>
    <message>
        <source>Unable to convert audio file!</source>
        <translation type="obsolete">Kann die Audiodatei nicht konvertieren!</translation>
    </message>
    <message>
        <source>Upload Error</source>
        <translation type="obsolete">Fehler beim Hochladen</translation>
    </message>
    <message>
        <source>Unable to upload audio file!</source>
        <translation type="obsolete">Kann die Audiodatei nicht hochladen!</translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation>Podcast löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation>Sind Sie sicher, daß sie diesen Podcast löschen wollen?</translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation>Lösche Podcast...</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Interner Fehler</translation>
    </message>
    <message>
        <source>Unable to generate purge command!</source>
        <translation type="obsolete">Kann den Löschbefehl nicht generieren!</translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation>Fehler an Gegenstelle</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
Continue deleting cast?</source>
        <translation type="obsolete">Kann das entfernte Audio nicht Löschen!
Podcast trotzdem löschen?</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Dateifehler</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation type="obsolete">Datei existiert nicht!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Kann die Datei nicht öffnen!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Nicht unterstützter Dateityp!</translation>
    </message>
    <message>
        <source> </source>
        <translation> </translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation>Zeige nur nichtabgelaufene Casts</translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation>Zeige nur aktive Casts</translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation>Fehler beim posten</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation>Kann die Audiodatei(en) auf dem anderen Server nicht löschen!</translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation>Der Server meldet: &quot;</translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation>Löschen des Podcasts fortsetzen?</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation>RDCastManager - Host</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation>Benutzer: [Unbekannt]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kann mich nicht verbinden</translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation>Schlüsselname</translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation>Feedname</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Casts</source>
        <translation>Casts</translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation>&amp;Zeige
Feed</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chliessen</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished">&amp;Auswählen</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-2.11.0.zip: rivendell-2.11.0/rdcastmanager/rdcastmanager_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation>Podcast editieren</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation>eMail des Autors:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation>Link URL:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Beschreibung:</translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation>Quelltext:</translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation>Quell-URL:</translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation>Kommentar-URL:</translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation>Gepostet am:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation>Cast läuft ab:</translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation type="obsolete">Läuft ab am/um:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Auswählen</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Hold</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation>Posting Status:</translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation>Episoden-
&amp;Report</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation>Sendezeit/-Datum:</translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation>Medienlink:</translation>
    </message>
    <message>
        <source>Expires On:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation>Podcastliste</translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation>Poste von
Car&amp;t/Cut</translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation>Poste von
&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation>Abonnement
&amp;Report</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chliessen</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>Herkunft</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Läuf ab</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation>Lade Audio hoch...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <source>Format Error</source>
        <translation type="obsolete">Formatfehler</translation>
    </message>
    <message>
        <source>Unable to convert audio file!</source>
        <translation type="obsolete">Kann die Audiodatei nicht konvertieren!</translation>
    </message>
    <message>
        <source>Upload Error</source>
        <translation type="obsolete">Fehler beim Hochladen</translation>
    </message>
    <message>
        <source>Unable to upload audio file!</source>
        <translation type="obsolete">Kann die Audiodatei nicht hochladen!</translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation>Podcast löschen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation>Sind Sie sicher, daß sie diesen Podcast löschen wollen?</translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation>Lösche Podcast...</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Interner Fehler</translation>
    </message>
    <message>
        <source>Unable to generate purge command!</source>
        <translation type="obsolete">Kann den Löschbefehl nicht generieren!</translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation>Fehler an Gegenstelle</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
Continue deleting cast?</source>
        <translation type="obsolete">Kann das entfernte Audio nicht Löschen!
Podcast trotzdem löschen?</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Dateifehler</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation type="obsolete">Datei existiert nicht!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Kann die Datei nicht öffnen!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Nicht unterstützter Dateityp!</translation>
    </message>
    <message>
        <source> </source>
        <translation> </translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation>Zeige nur nichtabgelaufene Casts</translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation>Zeige nur aktive Casts</translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation>Fehler beim posten</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation>Kann die Audiodatei(en) auf dem anderen Server nicht löschen!</translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation>Der Server meldet: &quot;</translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation>Löschen des Podcasts fortsetzen?</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation type="obsolete">RDCastManager - Host</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation>Benutzer: [Unbekannt]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kann mich nicht verbinden</translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation>Schlüsselname</translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation>Feedname</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Casts</source>
        <translation>Casts</translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation>&amp;Zeige
Feed</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chliessen</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished">&amp;Auswählen</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
